<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0">
<xsl:import href="page_Components.xsl" />
<xsl:param name="targetpath" />
<xsl:output method="html" name="html"/>
<xsl:template match="/">
<xsl:value-of select="$targetpath" /> 
<xsl:for-each select="/Document/chapter">
<xsl:variable name="tocfile" select="concat($targetpath,'/TOC0_',@id,'.htm')"/>
Generiere <xsl:value-of select="$tocfile"/><xsl:text>
</xsl:text>
<!--output method mit NAME text ist wichtig, damit sich result-document darauf beziehen kann
<xsl:result-document href="{$tabfile}" format="text">-->
<xsl:result-document href="{$tocfile}" format="html"
method="html">
<html>
<head>
<LINK REL="stylesheet" type="text/css" href="toc.css"></LINK>
<meta content="text/html; charset=utf-8" http-equiv="Content-Type"/>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
</head>


<body>
<xsl:call-template name="toc_head" />
<xsl:call-template name="createToc" >
<xsl:with-param name="currentFocus" select="@id" />
</xsl:call-template>
<xsl:call-template name="toc_foot" />
</body>
</html>
</xsl:result-document>
</xsl:for-each>

</xsl:template>
<xsl:template name="createToc">
<xsl:param name="currentFocus" />
<xsl:for-each select="/Document/chapter">
<xsl:variable name="p_class">
<xsl:choose>
<xsl:when test="@id=$currentFocus">
<xsl:text>Fokus</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:text>listlevel</xsl:text>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:variable name="a_class">
<xsl:choose>
<xsl:when test="@id=$currentFocus">
<xsl:text>fokus</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:text></xsl:text>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="isVisible">
<xsl:call-template name="isVisibleTocEntry">
<xsl:with-param name="currentFocus" select="$currentFocus"/>
<xsl:with-param name="targetChapter" select="@id"/>
</xsl:call-template>
</xsl:variable>
<xsl:if test="contains($isVisible,'true')">
<p><xsl:attribute name="class"><xsl:value-of select="$p_class" /><xsl:value-of select="@level" /></xsl:attribute>
<a target="_parent" class="{$a_class}">
<xsl:attribute name="href"><xsl:value-of select="concat('f_',fileName,'.htm')" /></xsl:attribute><xsl:if test="chapterNumber != ''"><span class="chapterNumber">
<xsl:value-of select="chapterNumber"/></span><xsl:text>&#160;</xsl:text></xsl:if><xsl:value-of select="shortName"/>
<!--zum debuggen: <xsl:value-of select="$isVisible" />-->
</a> </p>
</xsl:if>
</xsl:for-each>

</xsl:template>
<xsl:template name="isVisibleTocEntry">
<xsl:param name="currentFocus" />
<xsl:param name="targetChapter" />
<xsl:choose>
<xsl:when test="$currentFocus=$targetChapter">
<xsl:text>true</xsl:text>
</xsl:when>
<xsl:otherwise>
<!--die Zielknoten auf Ebene 1 kommen immer rein-->
<xsl:variable name="levelofTargetChapter">
<xsl:call-template name="getLevel">
<xsl:with-param name="targetChapter" select="$targetChapter" />
</xsl:call-template>
</xsl:variable>
<!--die Zielknoten liegen direkt unter dem Fokus?-->
<xsl:variable name="parentofTargetChapter">
<xsl:call-template name="getParent">
<xsl:with-param name="targetChapter" select="$targetChapter" />
</xsl:call-template>
</xsl:variable>
<xsl:choose>
<xsl:when test="$parentofTargetChapter=$currentFocus or $levelofTargetChapter='1'">
<xsl:text>true</xsl:text>
</xsl:when>
<xsl:otherwise>
<!--der targetChapter ist ein parent von currentFocus?-->
<xsl:call-template name="getParentOfCurrentFocus">
<xsl:with-param name="targetChapter" select="$targetChapter" />
<xsl:with-param name="currentFocus" select="$currentFocus"/>
<xsl:with-param name="numberOfCalls" select="0"/>

</xsl:call-template>
</xsl:otherwise>
</xsl:choose>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template name="getParentOfCurrentFocus">
<xsl:param name="targetChapter" />
<xsl:param name="currentFocus" />
<xsl:param name="numberOfCalls" />
<xsl:variable name="parentOfCurrentFocus">
<xsl:call-template name="getParent">
<xsl:with-param name="targetChapter" select="$currentFocus" />
</xsl:call-template>
</xsl:variable>
<xsl:variable name="parentOfTargetChapter">
<xsl:call-template name="getParent">
<xsl:with-param name="targetChapter" select="$targetChapter" />
</xsl:call-template>
</xsl:variable>
<xsl:choose>
<!--entweder das Zielkapitel ist direkt übergeordnet, oder 
 der parent des akt. Fokus ist identisch mit dem parent des Zielkapitels-->
<xsl:when test="$parentOfCurrentFocus=$targetChapter or ($parentOfCurrentFocus=$parentOfTargetChapter and $numberOfCalls &lt; 2)">
<xsl:text>true</xsl:text>
</xsl:when>
<xsl:when test="$parentOfCurrentFocus=-1">
<xsl:text>false</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:call-template name="getParentOfCurrentFocus">
<xsl:with-param name="targetChapter" select="$targetChapter" />
<xsl:with-param name="currentFocus" select="$parentOfCurrentFocus"/>
<xsl:with-param name="numberOfCalls" select="$numberOfCalls+1"/>
</xsl:call-template>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
<xsl:template name="getLevel">
<xsl:param name="targetChapter" />
<xsl:value-of select="/Document/chapter [@id=$targetChapter]/@level"/>

</xsl:template>
<xsl:template name="getParent">
<xsl:param name="targetChapter" />
<xsl:value-of select="/Document/chapter [@id=$targetChapter]/@parent"/>

</xsl:template>

<!--klappt noch nicht:
<xsl:template name="computeDistance">
<xsl:param name="currentFocus" />
<xsl:param name="targetChapter" />
<xsl:choose>
<xsl:when test="$currentFocus=$targetChapter">
<xsl:text>0</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:variable name="levelFrom">
<xsl:call-template name="getLevel">
<xsl:with-param name="targetChapter" select="$currentFocus" />
</xsl:call-template>
</xsl:variable>
<xsl:variable name="levelTo">
<xsl:call-template name="getLevel">
<xsl:with-param name="targetChapter" select="$targetChapter" />
</xsl:call-template>
</xsl:variable>

<xsl:choose>
<xsl:when test="$levelFrom &gt; $levelTo">
<xsl:text>goUp: </xsl:text>
<xsl:call-template name="stepUpCurrentFocus">
<xsl:with-param name="counter" select="1" />
<xsl:with-param name="targetChapter" select="$targetChapter" />
<xsl:with-param name="currentFocus" select="$currentFocus" />
</xsl:call-template>

</xsl:when>
<xsl:otherwise>
<xsl:text>goDown</xsl:text>
</xsl:otherwise>
</xsl:choose>

</xsl:otherwise>
</xsl:choose>


</xsl:template>
<xsl:template name="stepUpCurrentFocus">
<xsl:param name="counter"/>
<xsl:param name="targetChapter" />
<xsl:param name="currentFocus" />
<xsl:variable name="parentOfCurrentFocus">
<xsl:call-template name="getParent">
<xsl:with-param name="targetChapter" select="$currentFocus" />
</xsl:call-template>
</xsl:variable>
<xsl:choose>
<xsl:when test="$parentOfCurrentFocus=$targetChapter or $parentOfCurrentFocus='-1'">
<xsl:value-of select="concat(' currFocus ',$parentOfCurrentFocus,'_',$counter)"/>
</xsl:when>
<xsl:otherwise>

<xsl:variable name="levelFrom">
<xsl:call-template name="getLevel">
<xsl:with-param name="targetChapter" select="$parentOfCurrentFocus" />
</xsl:call-template>
</xsl:variable>
<xsl:variable name="levelTo">
<xsl:call-template name="getLevel">
<xsl:with-param name="targetChapter" select="$targetChapter" />
</xsl:call-template>
</xsl:variable>

<xsl:choose>
<xsl:when test="$levelTo &gt; $levelFrom ">
<xsl:variable name="parent">
<xsl:call-template name="getParent">
<xsl:with-param name="targetChapter" select="$targetChapter" />
</xsl:call-template>
</xsl:variable>
<xsl:call-template name="stepUpTargetChapter">
<xsl:with-param name="counter" select="$counter+1" />
<xsl:with-param name="targetChapter" select="$currentFocus" />
<xsl:with-param name="currentFocus" select="$parent" />
</xsl:call-template>
</xsl:when>
<xsl:otherwise>
<xsl:variable name="parent">
<xsl:call-template name="getParent">
<xsl:with-param name="targetChapter" select="$parentOfCurrentFocus" />
</xsl:call-template>
</xsl:variable>
<xsl:call-template name="stepUpCurrentFocus">
<xsl:with-param name="counter" select="$counter+1" />
<xsl:with-param name="targetChapter" select="$targetChapter" />
<xsl:with-param name="currentFocus" select="$parent" />
</xsl:call-template>
</xsl:otherwise>
</xsl:choose>

</xsl:otherwise>
</xsl:choose>
</xsl:template>
<xsl:template name="stepUpTargetChapter">
<xsl:param name="counter"/>
<xsl:param name="targetChapter" />
<xsl:param name="currentFocus" />
<xsl:variable name="parentOfTargetChapter">
<xsl:call-template name="getParent">
<xsl:with-param name="targetChapter" select="$targetChapter" />
</xsl:call-template>
</xsl:variable>
<xsl:choose>
<xsl:when test="$parentOfTargetChapter=$currentFocus or $parentOfTargetChapter='-1'">
<xsl:value-of select="concat(' TargetChapter ',$currentFocus,'_',$counter)"/>
</xsl:when>
<xsl:otherwise>

<xsl:variable name="levelFrom">
<xsl:call-template name="getLevel">
<xsl:with-param name="targetChapter" select="$parentOfTargetChapter" />
</xsl:call-template>
</xsl:variable>
<xsl:variable name="levelTo">
<xsl:call-template name="getLevel">
<xsl:with-param name="targetChapter" select="$currentFocus" />
</xsl:call-template>
</xsl:variable>

<xsl:choose>
<xsl:when test="$levelTo &gt; $levelFrom ">
<xsl:variable name="parent">
<xsl:call-template name="getParent">
<xsl:with-param name="targetChapter" select="$targetChapter" />
</xsl:call-template>
</xsl:variable>
<xsl:call-template name="stepUpTargetChapter">
<xsl:with-param name="counter" select="$counter+1" />
<xsl:with-param name="targetChapter" select="$currentFocus" />
<xsl:with-param name="currentFocus" select="$parent" />
</xsl:call-template>
</xsl:when>
<xsl:otherwise>
<xsl:variable name="parent">
<xsl:call-template name="getParent">
<xsl:with-param name="targetChapter" select="$parentOfTargetChapter" />
</xsl:call-template>
</xsl:variable>
<xsl:call-template name="stepUpCurrentFocus">
<xsl:with-param name="counter" select="$counter+1" />
<xsl:with-param name="targetChapter" select="$targetChapter" />
<xsl:with-param name="currentFocus" select="$parent" />
</xsl:call-template>
</xsl:otherwise>
</xsl:choose>

</xsl:otherwise>
</xsl:choose>
</xsl:template>-->
</xsl:stylesheet>