<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0">
<xsl:import href="page_Components.xsl" />
<xsl:param name="targetpath" />
<xsl:param name="pdf_file" />
<xsl:output method="xml" name="xml"/>

<xsl:template match="/">
<xsl:value-of select="$targetpath" /> 
<xsl:for-each select="/Document/chapter">
<xsl:variable name="bodyfile" select="concat($targetpath,'/f_',fileName,'.htm')"/>
<xsl:variable name="deeplinkpath" select="concat('http://www.superx-projekt.de',substring-after($targetpath,'webapps/superx'))"/>

Generiere <xsl:value-of select="$bodyfile"/> in <xsl:value-of select="$targetpath"/><xsl:text>
</xsl:text>
<!--output method mit NAME text ist wichtig, damit sich result-document darauf beziehen kann
<xsl:result-document href="{$tabfile}" format="text">-->
<xsl:result-document href="{$bodyfile}" format="xml"
method="xml">
<xsl:variable name="prev">
<xsl:call-template name="getFilename">
<xsl:with-param name="id" select="@prev" />
</xsl:call-template>
</xsl:variable>
<xsl:variable name="next">
<xsl:call-template name="getFilename">
<xsl:with-param name="id" select="@next" />
</xsl:call-template>
</xsl:variable>
<html>
<head><title><xsl:value-of select="name"/></title>
<META NAME = "author" content = "Daniel Quathamer"></META>
<META NAME = "copyright" content = "{concat('(c) ',format-dateTime(current-dateTime(),'[Y]'),' Daniel Quathamer')}"></META>
<META NAME = "date" content ="{format-dateTime(current-dateTime(),'[D].[M].[Y]')}"></META>
<meta http-equiv="content-type" content="text/html; charset=UTF-8" />
<LINK REL = "Start" href = "main.htm"></LINK>
<LINK REL = "Next" href="{$next}" />
<LINK REL = "Prev" href="{$prev}" />
<LINK REL = "Fokus" href="{$deeplinkpath}"/>
<style type="text/css"><xsl:text>
</xsl:text>
<xsl:value-of select="/Document/style"/>
</style>
<LINK REL="stylesheet" type="text/css" href="bulma.css"></LINK>
<LINK REL="stylesheet" type="text/css" href="memtext.css"></LINK>
<base target="_self" />
</head>
<body>
<xsl:call-template name="header" />

<xsl:variable name="header_tagname">
<xsl:choose>
<xsl:when test="@level=0">
<xsl:text>h1</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:value-of select="concat('h',@level)"/>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<section class="hero">
  <div class="hero-body">
    <div class="container">
<xsl:element name="{$header_tagname}"><xsl:if test="chapterNumber != ''"><span class="chapterNumber">
<xsl:value-of select="chapterNumber"/></span><xsl:text> </xsl:text></xsl:if>
<xsl:value-of select="name"/></xsl:element>
 </div>
 </div>
</section>
<div class="columns">
  <div class="column is-one-quarter">
  <aside class="menu"  style="background-color:#8ec4ff">
 
  
  <xsl:call-template name="createToc" >
<xsl:with-param name="currentFocus" select="@id" />
</xsl:call-template>
  
  
  </aside>  
  </div>
  <div class="column is-three-quarters">
  <div class="content">
<xsl:variable name="bodyText">
<xsl:value-of select="body"/>
</xsl:variable>
<xsl:choose>
<xsl:when test="$bodyText='#empty#'">
<xsl:variable name="currentId">
<xsl:value-of select="@id"/>
</xsl:variable>
<xsl:for-each select="/Document/chapter[@parent=$currentId]">
<p>
<xsl:call-template name="navigationButton">
<xsl:with-param name="targetChapterId" select="@id" />
<xsl:with-param name="caption" select="name" />
</xsl:call-template>
</p>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:copy-of select="$bodyText"/>
</xsl:otherwise>
</xsl:choose>
</div>
  </div>
  
 </div>     


  <div class="content has-text-centered">
    <nav class="level">
    

<!--prev-->
<xsl:call-template name="navigationButton">
<xsl:with-param name="targetChapterId" select="@prev" />
<xsl:with-param name="imgSrc" select="'resultset_previous.svg'" />
<xsl:with-param name="caption" select="'Vorherige'" />
</xsl:call-template>
<!--Hoch-->
<xsl:call-template name="navigationButton">
<xsl:with-param name="targetChapterId" select="0" />
<xsl:with-param name="imgSrc" select="'resultset_up.svg'" />
<xsl:with-param name="caption" select="'Hoch'" />
</xsl:call-template>
<!--Search-->
<xsl:call-template name="navigationButton">
<xsl:with-param name="targetHref"><xsl:text>javascript:document.location=('search/index.htm');</xsl:text></xsl:with-param>
<xsl:with-param name="imgSrc" select="'resultset_search.svg'" />
<xsl:with-param name="caption" select="'Suche'" />
<xsl:with-param name="target" select="'_self'" />
</xsl:call-template>
<!--next-->
<xsl:call-template name="navigationButton">
<xsl:with-param name="targetChapterId" select="@next" />
<xsl:with-param name="imgSrc" select="'resultset_next.svg'" />
<xsl:with-param name="caption" select="'Nächste'" />
</xsl:call-template>

</nav>
  </div>
<footer class="footer">
<xsl:variable name="fokus"><xsl:call-template name="getFilename">
<xsl:with-param name="id" select="@id" />
</xsl:call-template></xsl:variable>
<xsl:call-template name="footer" >
<xsl:with-param name="pdf_file" select="$pdf_file" />
<xsl:with-param name="fokus" select="concat('#targetpath#/',$fokus)" />
</xsl:call-template>
 </footer> 
</body>
</html>
</xsl:result-document>
</xsl:for-each>
</xsl:template>

<xsl:template name="getFilename">
<xsl:param name="id" />
<xsl:value-of select="concat('f_',/Document/chapter[@id=$id]/fileName,'.htm')"/>
</xsl:template>

<xsl:template name="getName">
<xsl:param name="id" />
<xsl:value-of select="/Document/chapter[@id=$id]/name"/>
</xsl:template>

<xsl:template name="navigationButton">
<xsl:param name="targetChapterId" />
<xsl:param name="imgSrc" />
<xsl:param name="caption" />
<xsl:param name="targetHref" />
<xsl:param name="target" select="'_self'"/>
<xsl:variable name="targetUrl">
<xsl:choose>
<xsl:when test="$targetHref != ''">
<xsl:value-of select="$targetHref"/>
</xsl:when>
<xsl:otherwise>
<xsl:call-template name="getFilename">
<xsl:with-param name="id" select="$targetChapterId" />
</xsl:call-template>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:variable name="targetName">
<xsl:choose>
<xsl:when test="string($targetChapterId) != '' ">
<xsl:call-template name="getName">
<xsl:with-param name="id" select="$targetChapterId" />
</xsl:call-template>
</xsl:when>
<xsl:otherwise>
<xsl:value-of select="$caption"/>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<div class="level-item">
    <div class="box">
   
    <xsl:if test="$imgSrc!=''">
     <p class="heading">
      <a name="{$caption}" href = "{$targetUrl}"
target = "{$target}"
class  = "Navigation"
title="{$targetName}" onMouseOver="this.style.textDecoration='underline';"
onMouseOut=" this.style.textDecoration='none';">
<IMG src="{$imgSrc}" ALT="{$targetName}" border="0" /></a>
</p>
</xsl:if>
      
      <p>
      
      <a name="{$caption}" href = "{$targetUrl}" target = "{$target}" class  = "Navigation"
title="{$targetName}" onMouseOver="this.style.textDecoration='underline';"
onMouseOut=" this.style.textDecoration='none';"><xsl:value-of select="$caption" /></a>
      </p>
   </div>
  </div>
</xsl:template>

<xsl:template name="createToc">
<xsl:param name="currentFocus" />
<xsl:for-each select="/Document/chapter[@id='0']">
<xsl:variable name="p_class">
<xsl:choose>
<xsl:when test="@id=$currentFocus">
<xsl:text>Fokus</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:text>listlevel</xsl:text>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:variable name="a_class">
<xsl:choose>
<xsl:when test="@id=$currentFocus">
<xsl:text>is-active</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:text></xsl:text>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="isVisible">
<xsl:call-template name="isVisibleTocEntry">
<xsl:with-param name="currentFocus" select="$currentFocus"/>
<xsl:with-param name="targetChapter" select="@id"/>
</xsl:call-template>
</xsl:variable>
<xsl:if test="contains($isVisible,'true')">
<ul class="menu-list"><li><xsl:attribute name="class"><xsl:value-of select="$p_class" /><xsl:value-of select="@level" /></xsl:attribute>
<a target="_self" class="{$a_class}">
<xsl:attribute name="href"><xsl:value-of select="concat('f_',fileName,'.htm')" /></xsl:attribute><xsl:if test="chapterNumber != ''"><span class="chapterNumber">
<xsl:value-of select="chapterNumber"/></span><xsl:text>&#160;</xsl:text></xsl:if><xsl:value-of select="shortName"/>
<!--zum debuggen: <xsl:value-of select="$isVisible" />-->
</a> 
<xsl:call-template name="getChildren">
<xsl:with-param name="parentId" select="@id"/>
<xsl:with-param name="currentFocus" select="$currentFocus"/>
</xsl:call-template>

</li></ul>
</xsl:if>
</xsl:for-each>

</xsl:template>

<xsl:template name="getChildren">
<xsl:param name="parentId" />
<xsl:param name="currentFocus"/>
<xsl:variable name="childrenCount">
<xsl:value-of select="count(/Document/chapter[@parent=$parentId])"/>
</xsl:variable>
<xsl:if test="$childrenCount !=0">
<ul class="menu-list">
<xsl:for-each select="/Document/chapter[@parent=$parentId]">
<xsl:variable name="isVisible">
<xsl:call-template name="isVisibleTocEntry">
<xsl:with-param name="currentFocus" select="$currentFocus"/>
<xsl:with-param name="targetChapter" select="@id"/>
</xsl:call-template>
</xsl:variable>

<xsl:variable name="a_class">
<xsl:choose>
<xsl:when test="@id=$currentFocus">
<xsl:text>is-active</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:text></xsl:text>
</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:if test="contains($isVisible,'true')">
<li>
<a target="_self" class="{$a_class}">
<xsl:attribute name="href"><xsl:value-of select="concat('f_',fileName,'.htm')" /></xsl:attribute><xsl:if test="chapterNumber != ''"><span class="chapterNumber">
<xsl:value-of select="chapterNumber"/></span><xsl:text>&#160;</xsl:text></xsl:if><xsl:value-of select="shortName"/>
<!--zum debuggen: <xsl:value-of select="$isVisible" />-->
</a> 
<xsl:call-template name="getChildren">
<xsl:with-param name="parentId" select="@id"/>
<xsl:with-param name="currentFocus" select="$currentFocus"/>
</xsl:call-template>
</li>
</xsl:if>
</xsl:for-each>
</ul>
</xsl:if>

</xsl:template>
<xsl:template name="isVisibleTocEntry">
<xsl:param name="currentFocus" />
<xsl:param name="targetChapter" />
<xsl:choose>
<xsl:when test="$currentFocus=$targetChapter">
<xsl:text>true</xsl:text>
</xsl:when>
<xsl:otherwise>
<!--die Zielknoten auf Ebene 1 kommen immer rein-->
<xsl:variable name="levelofTargetChapter">
<xsl:call-template name="getLevel">
<xsl:with-param name="targetChapter" select="$targetChapter" />
</xsl:call-template>
</xsl:variable>
<!--die Zielknoten liegen direkt unter dem Fokus?-->
<xsl:variable name="parentofTargetChapter">
<xsl:call-template name="getParent">
<xsl:with-param name="targetChapter" select="$targetChapter" />
</xsl:call-template>
</xsl:variable>
<xsl:choose>
<xsl:when test="$parentofTargetChapter=$currentFocus or $levelofTargetChapter='1'">
<xsl:text>true</xsl:text>
</xsl:when>
<xsl:otherwise>
<!--der targetChapter ist ein parent von currentFocus?-->
<xsl:call-template name="getParentOfCurrentFocus">
<xsl:with-param name="targetChapter" select="$targetChapter" />
<xsl:with-param name="currentFocus" select="$currentFocus"/>
<xsl:with-param name="numberOfCalls" select="0"/>

</xsl:call-template>
</xsl:otherwise>
</xsl:choose>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template name="getParentOfCurrentFocus">
<xsl:param name="targetChapter" />
<xsl:param name="currentFocus" />
<xsl:param name="numberOfCalls" />
<xsl:variable name="parentOfCurrentFocus">
<xsl:call-template name="getParent">
<xsl:with-param name="targetChapter" select="$currentFocus" />
</xsl:call-template>
</xsl:variable>
<xsl:variable name="parentOfTargetChapter">
<xsl:call-template name="getParent">
<xsl:with-param name="targetChapter" select="$targetChapter" />
</xsl:call-template>
</xsl:variable>
<xsl:choose>
<!--entweder das Zielkapitel ist direkt übergeordnet, oder 
 der parent des akt. Fokus ist identisch mit dem parent des Zielkapitels-->
<xsl:when test="$parentOfCurrentFocus=$targetChapter or ($parentOfCurrentFocus=$parentOfTargetChapter and $numberOfCalls &lt; 2)">
<xsl:text>true</xsl:text>
</xsl:when>
<xsl:when test="$parentOfCurrentFocus=-1">
<xsl:text>false</xsl:text>
</xsl:when>
<xsl:otherwise>
<xsl:call-template name="getParentOfCurrentFocus">
<xsl:with-param name="targetChapter" select="$targetChapter" />
<xsl:with-param name="currentFocus" select="$parentOfCurrentFocus"/>
<xsl:with-param name="numberOfCalls" select="$numberOfCalls+1"/>
</xsl:call-template>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
<xsl:template name="getLevel">
<xsl:param name="targetChapter" />
<xsl:value-of select="/Document/chapter [@id=$targetChapter]/@level"/>

</xsl:template>
<xsl:template name="getParent">
<xsl:param name="targetChapter" />
<xsl:value-of select="/Document/chapter [@id=$targetChapter]/@parent"/>

</xsl:template>

</xsl:stylesheet>